@@ -17,11 +17,12 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* start of config.h */
+#ifndef __CONFIG_H__
+#define __CONFIG_H__
 @TOP@
 
-/* define this if you want to use SYSV regex instead of POSIX regex */
-#undef SYSVREGEX
+/* define this to the version string for this program */
+#undef VERSION
 
 /* define this if you want to enable www-sql's recursive extensions */
 #undef RECURSIVE
@@ -30,6 +31,13 @@
    people to use www-sql as an action handler (thus blocking a security
    hole) */
 #undef ONLY_APACHE_ACTION
-@BOTTOM@
-/* end of config.h */
 
+/* This define enables some unsafe functions such as exec in www-sql.  It
+   also relaxes the checking for the include statement. */
+#undef ENABLE_UNSAFE
+
+/* define this if you are compiling with the new scanner module */
+#undef NEW_SCANNER
+
+@BOTTOM@
+#endif /* __CONFIG_H__ */
