@@ -31,8 +31,8 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
-char *xstrdup();
-void *xmalloc();
+char *xstrdup(const char *str);
+void *xmalloc(int size);
 
 typedef struct variable {
   char *name, *value;
