@@ -32,9 +32,9 @@ extern VAR *firstVar;
 /* function prototypes */
 void initCGI();
 
-void setVar(char *, char *);
-void setDefault(char *, char *);
-char *valueOf(char *);
+void setVar(const char *name, const char *value);
+void setDefault(const char *name, const char *value);
+char *valueOf(const char *);
 
 /* returns a newly malloc'd, url encoded version of the string */
 char *escape_string(char *);
