@@ -29,7 +29,7 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
-void *xmalloc();
+void *xmalloc(int size);
 
 #include "cmds.h"
 #include "if.h"
@@ -70,6 +70,7 @@ void cmdIf(int argc, char *argv[]) {
     is->active = 1;
 #ifdef NEW_SCANNER
     is->loop_type = LOOP_IF;
+    is->looping = 0;
 #endif
     is->prev = curIf;
     curIf = is;
@@ -79,6 +80,7 @@ void cmdIf(int argc, char *argv[]) {
     is->active = 0;               /* up the elses and endifs         */
 #ifdef NEW_SCANNER
     is->loop_type = LOOP_IF;
+    is->looping = 0;
 #endif
     is->prev = curIf;
     curIf = is;
@@ -265,6 +267,10 @@ void cmdContinue(int argc, char *argv[]) {
 }
 #endif
 
+#ifdef NEW_SCANNER
+void cmdInclude(int argc, char *argv[]);
+#endif
+
 commands if_funcs = {
   {"else",  cmdElse},
   {"elsif", cmdElsIf},
@@ -276,6 +282,7 @@ commands if_funcs = {
   {"done",       cmdDone},
   {"break",      cmdBreak},
   {"continue",   cmdContinue},
+  {"uinclude",   cmdInclude},
 #endif
   {NULL, NULL}
 };
