@@ -188,12 +188,14 @@ void cmdQuery(int argc, char *argv[]) {
   if (mysql_query(conn, tmp) < 0) {
     fprintf(yyout, "<p>Query failed: %s</p>\n", mysql_error(conn));
     free(tmp);
+    setVar("AFFECTED_ROWS", "0");
+    setVar("INSERT_ID", "-1");
     return;
   }
   free(tmp);
-  sprintf(buf, "%li", mysql_affected_rows(conn));
+  sprintf(buf, "%ld", mysql_affected_rows(conn));
   setVar("AFFECTED_ROWS", buf);
-  sprintf(buf, "%li", mysql_insert_id(conn));
+  sprintf(buf, "%ld", mysql_insert_id(conn));
   setVar("INSERT_ID", buf);
   /* if the query has no body, don't set up query handle (ie for INSERT) */
   if ((res = mysql_store_result(conn)) == NULL) {
@@ -213,9 +215,9 @@ void cmdQuery(int argc, char *argv[]) {
   qh->next = firstQuery;
   firstQuery = qh;
 
-  sprintf(buf, "%i", mysql_num_fields(qh->res));
+  sprintf(buf, "%d", mysql_num_fields(qh->res));
   setVar("NUM_FIELDS", buf);
-  sprintf(buf, "%li", mysql_num_rows(qh->res));
+  sprintf(buf, "%ld", mysql_num_rows(qh->res));
   setVar("NUM_ROWS", buf);
 }
 
