@@ -38,7 +38,7 @@ static char yysccsid[] = "@(#)yaccpar	1.9 (Berkeley) 02/21/93";
 #include <regex.h>
 
 extern FILE *yyout;
-void *xmalloc(int);
+void *xmalloc(int size);
 #line 34 "newexpr.y"
 typedef union {
   double d;
