@@ -212,6 +212,8 @@ void cmdQuery(int argc, char *argv[]) {
   free(tmp);
   if (res == NULL) {
     fprintf(yyout, "<p>Query failed: %s</p>\n", PQerrorMessage(conn));
+    setVar("AFFECTED_ROWS", "0");
+    setVar("INSERT_ID", "-1");
     return;
   }
   switch (PQresultStatus(res)) {
@@ -241,9 +243,9 @@ void cmdQuery(int argc, char *argv[]) {
       firstQuery = qh;
       setVar("AFFECTED_ROWS", "0");
       setVar("INSERT_ID",     "-1");
-      sprintf(buf, "%i", PQnfields(qh->res));
+      sprintf(buf, "%d", PQnfields(qh->res));
       setVar("NUM_FIELDS", buf);
-      sprintf(buf, "%i", PQntuples(qh->res));
+      sprintf(buf, "%d", PQntuples(qh->res));
       setVar("NUM_ROWS", buf);
       break;
     case PGRES_COMMAND_OK:
