@@ -28,7 +28,7 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
-char *xstrdup();
+char *xstrdup(const char *str);
 
 #include "cgi.h"
 #include "if.h"
